-----------------------------------------------------------------------------------------------
-- Client Lua Script for HUDAlerts
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"
require "GameLib"
require "Apollo"
require "CommunicatorLib"
require "DatacubeLib"
require "PathEpisode"
require "QuestLib"

local SuppressVacuum = {}
local svSuppressVacuum = 0
local svTimer = nil

function SuppressVacuum:new(o)
	o = o or {}
	setmetatable(o, self)
	self.__index = self
	return o
end

function SuppressVacuum:Init()
	local tDependencies = {
		"HUDAlerts",
	}
	Apollo.RegisterAddon(self, false, "", tDependencies)
end

function SuppressVacuum:OnLoad()
	self.xmlDoc = XmlDoc.CreateFromFile("SuppressVacuum.xml")
	self.xmlDoc:RegisterCallback("OnDocumentReady", self) 

	Apollo.RegisterSlashCommand("sv", "SetSuppressVacuum", self)
end

function SuppressVacuum:OnSave(eType)
	if eType == GameLib.CodeEnumAddonSaveLevel.Account then
		tData = {}
	        tData.svSuppressVacuum = svSuppressVacuum
		return tData
        end
end

function SuppressVacuum:OnRestore(eType, tSavedData)
	if eType == GameLib.CodeEnumAddonSaveLevel.Account then 
		svSuppressVacuum = 0
		if tSavedData.svSuppressVacuum then
		        svSuppressVacuum = tSavedData.svSuppressVacuum
	        end
        end
end

function SuppressVacuum:OnDocumentReady()
	if  self.xmlDoc == nil then
		return
	end

        self:Change_OnCanVacuumChanged()
        self:Add_HideLootAlert()
end


function SuppressVacuum:Add_HideLootAlert()
	local HUDAlerts = Apollo.GetAddon("HUDAlerts")
	if not HUDAlerts then return nil end

	function HUDAlerts:HideLootAlert()
		self.wndLootAlert:Show(false)
		SuppressVacuum.svTimer:Stop()
	end
end

function SuppressVacuum:SetSuppressVacuum(strCmd, strParam)
	if strParam == "" then
	else 
		local time = tonumber(strParam)
		if time and time > 0 then
			svSuppressVacuum = time
		else
			svSuppressVacuum = 0
		end
	end
	Print("Suppress Vacuum set to: " .. svSuppressVacuum)
end

function SuppressVacuum:Change_OnCanVacuumChanged()
	local HUDAlerts = Apollo.GetAddon("HUDAlerts")
	if not HUDAlerts then return nil end

	function HUDAlerts:OnCanVacuumChanged(bCanVacuum)
		local strKeybind = GameLib.GetKeyBinding("VacuumLoot")
		self.wndLootAlert:FindChild("AlertItemKeybindText"):SetText(strKeybind)
		self.wndLootAlert:FindChild("AlertItemKeybind"):Show(strKeybind ~= Apollo.GetString("HUDAlert_Unbound"))
	
		if not self.wndLootAlert:IsShown() and bCanVacuum then
			self.wndLootAlert:Show(bCanVacuum, true)
			self.wndLootAlert:FindChild("AlertItemTransition"):SetSprite("sprAlert_SectionGlowRingFlash")
		else
			self.wndLootAlert:Show(bCanVacuum)
		end

		if svSuppressVacuum > 0 then
			if SuppressVacuum.svTimer ~= nil then
				SuppressVacuum.svTimer:Stop()
			end
			SuppressVacuum.svTimer = ApolloTimer.Create(svSuppressVacuum, true, "HideLootAlert", HUDAlerts);
		end
	
		self:OnUpdateInventory() -- Check Full Bag Indicator
	
		self.wndAlertContainer:ArrangeChildrenHorz(Window.CodeEnumArrangeOrigin.LeftOrTop)
		--self.wndLootAlert:FindChild("AlertItemTransition"):SetSprite("sprWinAnim_BirthSmallTemp") -- No Anim for vacuum
	end
end

local SuppressVacuumInst = SuppressVacuum:new()
SuppressVacuum:Init()
